@@ -1,10 +1,8 @@
 import contextlib
-import difflib
 import functools
 import itertools
 import math
 import numbers
-import os
 import warnings
 
 import numpy as np
@@ -281,6 +279,11 @@ def assert_eq(
     a_original = a
     b_original = b
 
+    if isinstance(a, (list, int, float)):
+        a = np.array(a)
+    if isinstance(b, (list, int, float)):
+        b = np.array(b)
+
     a, adt, a_meta, a_computed = _get_dt_meta_computed(
         a, check_shape=check_shape, check_graph=check_graph, check_chunks=check_chunks
     )
@@ -289,13 +292,7 @@ def assert_eq(
     )
 
     if str(adt) != str(bdt):
-        # Ignore check for matching length of flexible dtypes, since Array._meta
-        # can't encode that information
-        if adt.type == bdt.type and not (adt.type == np.bytes_ or adt.type == np.str_):
-            diff = difflib.ndiff(str(adt).splitlines(), str(bdt).splitlines())
-            raise AssertionError(
-                "string repr are different" + os.linesep + os.linesep.join(diff)
-            )
+        raise AssertionError(f"a and b have different dtypes: (a: {adt}, b: {bdt})")
 
     try:
         assert (
